SystemOrganization addCategory: #ConfigurationOfSoup!

Object subclass: #ConfigurationOfSoup
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSoup'!

!ConfigurationOfSoup commentStamp: 'StephaneDucasse 12/31/2011 10:32' prior: 0!
Soup is a library to perform HTML scrapping.

(ConfigurationOfSoup project version: #'stable') load

(ConfigurationOfSoup project version: '1.0') load
!

!ConfigurationOfSoup class methodsFor: 'private' stamp: 'sd 1/13/2011 16:29'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSoup class methodsFor: 'private' stamp: 'sd 1/13/2011 16:29'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfSoup class methodsFor: 'metacello support' stamp: 'sd 1/13/2011 16:28'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSoup class methodsFor: 'metacello support' stamp: 'sd 1/13/2011 16:28'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSoup class methodsFor: 'load' stamp: 'sd 1/13/2011 16:27'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfSoup class methodsFor: 'load' stamp: 'sd 1/13/2011 16:31'!
loadDefault
	"self loadDefault"

	"^ self loadMostRecentCoreWithTests"
	^ self load.! !

!ConfigurationOfSoup class methodsFor: 'load' stamp: 'sd 1/13/2011 16:28'!
loadMostRecentCoreWithTests
	^self project lastVersion load: #('Core' 'Tests')! !

!ConfigurationOfSoup class methodsFor: 'metacello support' stamp: 'sd 1/13/2011 16:28'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSoup class methodsFor: 'accessing' stamp: 'sd 1/13/2011 16:27'!
project

	^self new project! !

!ConfigurationOfSoup class methodsFor: 'metacello support' stamp: 'sd 1/13/2011 16:28'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfSoup methodsFor: 'baselines' stamp: 'sd 12/31/2011 12:44'!
baseline10: spec 
	<version: '1.0-baseline'> 
	
	spec for: #pharo do: [ 
		spec blessing: #baseline.
		spec description: 'First Full Configuration'. 
		spec author: 'StephaneDucasse'.
		spec timestamp: '29/12/2011 12:29'.
		spec repository: 'http://www.squeaksource.com/Soup'.
		
		spec 
			package: 'Soup-Core' with: [spec requires: 'XMLSupport' ];
			package: 'Soup-Tests-Core' with: [spec requires: 'Soup-Core'] ;
			package: 'Soup-Help' with: [spec requires: 'Soup-Core'].
			
		spec project: 'XMLSupport' with: [
			spec className: 'ConfigurationOfXMLSupport';
			versionString: #stable;
			repository: 'http://www.squeaksource.com/XMLSupport'.
			]
		
		]
	! !

!ConfigurationOfSoup methodsFor: 'baselines' stamp: 'StephaneDucasse 12/31/2011 14:22'!
baseline11: spec 
	<version: '1.1-baseline'> 
	
	spec for: #pharo do: [ 
		spec blessing: #baseline.
		spec description: 'Adding Camillo Bruni XPath extension'. 
		spec author: 'StephaneDucasse'.
		spec timestamp: '31/12/2011 12:29'.
		spec repository: 'http://www.squeaksource.com/Soup'.
		
		spec 
			package: 'Soup-Core' with: [spec requires: 'XMLSupport' ];
			package: 'Soup-Tests-Core' with: [spec requires: 'Soup-Core'] ;
			package: 'Soup-Help' with: [spec requires: 'Soup-Core'];
			package: 'Soup-XPath' with: [spec requires: 'Soup-Core'].
			
		spec project: 'XMLSupport' with: [
			spec className: 'ConfigurationOfXMLSupport';
			versionString: #stable;
			repository: 'http://www.squeaksource.com/XMLSupport'.
			]
		
		]
	! !

!ConfigurationOfSoup methodsFor: 'symbolic versions' stamp: 'StephaneDucasse 12/31/2011 14:23'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'pharo1.3.x' version: '1.1'.
	spec for: #'pharo1.4.x' version: '1.1'.
! !

!ConfigurationOfSoup methodsFor: 'accessing' stamp: 'sd 1/7/2011 10:26'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSoup methodsFor: 'symbolic versions' stamp: 'AlexandreBergel 1/17/2012 16:15'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'pharo1.3.x' version: '0.2'.
	spec for: #'pharo1.4.x' version: '0.2'.	! !

!ConfigurationOfSoup methodsFor: 'version' stamp: 'sd 1/13/2011 16:14'!
version01: spec 

	<version: '0.1'> 
	spec for: #common do: [ spec repository: 'http://www.squeaksource.com/Soup'. 
	spec 
		package: 'Soup-Core' with: 'Soup-Core-StephaneDucasse.6'; 
		package: 'Soup-Tests-Core' with: 'Soup-Tests-Core-StephaneDucasse.2';
		package: 'Soup-Help' with: 'Soup-Help-StephaneDucasse.2' ].! !

!ConfigurationOfSoup methodsFor: 'version' stamp: 'sd 3/27/2011 19:21'!
version02: spec 

	<version: '0.2'> 
	spec for: #common do: [ spec repository: 'http://www.squeaksource.com/Soup'. 
	spec 
		package: 'Soup-Core' with: 'Soup-Core-sd.11'; 
		package: 'Soup-Tests-Core' with: 'Soup-Tests-Core-sd.3';
		package: 'Soup-Help' with: 'Soup-Help-StephaneDucasse.2' ].! !

!ConfigurationOfSoup methodsFor: 'version' stamp: 'AlexandreBergel 1/17/2012 16:18'!
version10: spec
	<version: '1.1' imports: #('1.1-baseline' )>

	spec for: #'pharo' do: [
		spec blessing: #'development'.
		spec project: 'XMLSupport' with: [
				spec
					versionString: '1.2.0';
					loads: #('XML-Parser' 'XML-Tests-Parser' ) ].
		spec 
			package: 'Soup-Core' with: 'Soup-Core-CamilloBruni.14';
			package: 'Soup-Tests-Core' with: 'Soup-Tests-Core-AlexandreBergel.5';
			package: 'Soup-Help' with: 'Soup-Help-StephaneDucasse.2';
			package: 'Soup-XPath' with: 'Soup-XPath-CamilloBruni.3'. ].
! !
